@@ -1,10 +1,9 @@
-from codepack.storage import MemoryStorage, FileStorage, MongoStorage, MemoryJobStore, MongoJobStore, MemoryMessenger
+from codepack.storages import MemoryStorage, FileStorage, MongoStorage, MemoryMessenger
 from codepack import DeliveryService, CallbackService, SnapshotService,\
-    Scheduler, Worker, Supervisor, DockerManager, InterpreterManager, Default
+    Scheduler, Worker, Supervisor, DockerManager, InterpreterManager, Default, JobStore, StorableJob
 from unittest.mock import patch
 from collections.abc import Callable
 import os
-import inspect
 import logging
 
 
@@ -43,7 +42,7 @@ def test_default_init_with_config_path():
 
 def test_default_init_with_config_path_and_alias_path_os_env():
     try:
-        os.environ['CODEPACK_ALIAS_PATH'] = 'codepack/config/default/alias.ini'
+        os.environ['CODEPACK_ALIAS_PATH'] = 'codepack/utils/config/default/alias.ini'
         Default(config_path='config/test.ini')
         assert len(Default.instances) == 0
         assert Default.config is not None
@@ -55,7 +54,7 @@ def test_default_init_with_config_path_and_alias_path_os_env():
 
 
 def test_default_init_with_alias_path():
-    Default(alias_path='codepack/config/default/alias.ini')
+    Default(alias_path='codepack/utils/config/default/alias.ini')
     assert len(Default.instances) == 0
     assert Default.config is not None
     assert Default.config.config_path is None
@@ -97,14 +96,14 @@ def test_default_get_class_from_alias():
         os.environ.pop('CODEPACK_ALIAS_MEMORY_STORAGE', None)
         Default.config = None
         Default.alias = None
-        os.environ['CODEPACK_ALIAS_PATH'] = 'codepack/config/default/alias.ini'
+        os.environ['CODEPACK_ALIAS_PATH'] = 'codepack/utils/config/default/alias.ini'
         memory_storage = Default.get_class_from_alias(alias='memory_storage')
         assert isinstance(memory_storage, MemoryStorage.__class__)
         os.environ.pop('CODEPACK_ALIAS_PATH', None)
         Default.config = None
         Default.alias = None
         memory_storage = Default.get_class_from_alias(alias='memory_storage',
-                                                      alias_path='codepack/config/default/alias.ini')
+                                                      alias_path='codepack/utils/config/default/alias.ini')
         assert isinstance(memory_storage, MemoryStorage.__class__)
         Default.config = None
         Default.alias = None
@@ -129,7 +128,10 @@ def test_get_default_scheduler():
     assert isinstance(scheduler, Scheduler)
     assert 'codepack' in scheduler.jobstores
     jobstore = scheduler.jobstores['codepack']
-    assert isinstance(jobstore, MemoryJobStore)
+    assert hasattr(jobstore, 'storage')
+    assert isinstance(jobstore.storage, MemoryStorage)
+    assert jobstore.storage.item_type == StorableJob
+    assert jobstore.storage.key == 'id'
     assert scheduler.supervisor is None
 
 
@@ -145,11 +147,14 @@ def test_get_default_scheduler_with_some_os_env(mock_client):
         assert isinstance(scheduler, Scheduler)
         assert 'codepack' in scheduler.jobstores
         jobstore = scheduler.jobstores['codepack']
-        assert isinstance(jobstore, MongoJobStore)
+        assert hasattr(jobstore, 'storage')
+        assert isinstance(jobstore.storage, MongoStorage)
+        assert jobstore.storage.db == 'test_db'
+        assert jobstore.storage.collection == 'test_collection'
+        assert jobstore.storage.item_type == StorableJob
+        assert jobstore.storage.key == 'id'
         assert scheduler.supervisor == 'dummy_supervisor'
         mock_client.assert_called_once_with(host='localhost', port=27017, replicaset='TEST')
-        mock_client().__getitem__.assert_called_once_with('test_db')
-        mock_client().__getitem__().__getitem__.assert_called_once_with('test_collection')
     finally:
         os.environ.pop('CODEPACK_SCHEDULER_SOURCE', None)
         os.environ.pop('CODEPACK_SCHEDULER_DB', None)
